@@ -9,6 +9,7 @@
 # Copyright ©2011-2025. Hunan xxxxxxx Company limited. All rights reserved.
 # ---------------------------------------------------------------------------------------------------------
 """
+import time
 import asyncio
 from logging import Logger
 from urllib.parse import parse_qs
@@ -64,41 +65,54 @@ class BasePo(object):
     async def exists_one(locator):
         return await locator.count() == 1
 
-    async def get_locator(self, selector: str, timeout: float = 3.0) -> Locator:
+    @staticmethod
+    async def _wait_for_visible(locator: Locator, timeout: float, strict: bool = False) -> Locator:
+        """内部通用等待逻辑"""
+        if strict:
+            try:
+                await locator.first.wait_for(state='visible', timeout=timeout * 1000)
+                return locator
+            except PlaywrightTimeoutError as e:
+                raise PlaywrightTimeoutError(f"元素未在 {timeout} 秒内变为可见（严格模式）") from e
+            except Exception as e:
+                raise RuntimeError(f"检查元素时发生错误: {str(e)}") from e
+
+        # 快速模式：attached 超时设为 min(2秒, 总超时)
+        attached_timeout_ms = min(2000.0, timeout * 1000.0)  # 明确为 float，但实际传给 wait_for 会被转为 int
+        await locator.first.wait_for(state='attached', timeout=int(attached_timeout_ms))
+
+        end_time = time.time() + timeout
+        while time.time() < end_time:
+            if await locator.is_visible():
+                return locator
+            await asyncio.sleep(0.1)
+
+        raise PlaywrightTimeoutError(f"元素未在 {timeout} 秒内变为可见（快速模式）")
+
+    async def get_locator(self, selector: str, timeout: float = 3.0, strict: bool = True) -> Locator:
         """
         获取页面元素locator
         :param selector: 选择器表达式
         :param timeout: 超时时间（秒）
+        :param strict: 是否使用严格模式（Playwright标准可见性检查）
         :return: 元素对象
-        :return:
         """
         locator = self.__page.locator(selector)
-        try:
-            await locator.first.wait_for(state='visible', timeout=timeout * 1000)
-            return locator
-        except (PlaywrightTimeoutError,):
-            raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
-        except Exception as e:
-            raise RuntimeError(f"检查元素时发生错误: {str(e)}")
+        return await self._wait_for_visible(locator, timeout, strict)
 
     @staticmethod
-    async def get_sub_locator(locator: Locator, selector: str, timeout: float = 3.0) -> Locator:
+    async def get_sub_locator(locator: Locator, selector: str, timeout: float = 3.0, strict: bool = True) -> Locator:
         """
         获取页面locator的子locator
         :param locator: 页面Locator对象
         :param selector: 选择器表达式
         :param timeout: 超时时间（秒）
+        :param strict: 是否使用严格模式（Playwright标准可见性检查）
         :return: 元素对象
         :return:
         """
-        locator_inner = locator.locator(selector)
-        try:
-            await locator_inner.first.wait_for(state='visible', timeout=timeout * 1000)
-            return locator_inner
-        except (PlaywrightTimeoutError,):
-            raise PlaywrightTimeoutError(f"元素 '{selector}' 未在 {timeout} 秒内找到")
-        except Exception as e:
-            raise RuntimeError(f"检查元素时发生错误: {str(e)}")
+        sub_locator = locator.locator(selector)
+        return await BasePo._wait_for_visible(sub_locator, timeout, strict)
 
     @classmethod
     async def handle_po_cookie_tip(cls, page: Any, logger: Optional[Logger] = None, timeout: float = 3.0,
@@ -168,23 +182,24 @@ class BasePo(object):
                     "method": request.method,
                     "resource_type": request.resource_type,
                     "headers": dict(request.headers),
+                    "post_data": safe_parse_literal(s=request.post_data)
+
                 }
                 if include_post_data:
-                    if "application/json" in request.headers.get("content-type"):
-                        record["post_data"] = request.post_data_json
-                    elif "application/x-www-form-urlencoded" in request.headers.get("content-type"):
+                    if "application/json" in (request.headers.get("content-type") or "").lower():
+                        if request.post_data_json:
+                            record["post_data"] = request.post_data_json
+                    elif "application/x-www-form-urlencoded" in (request.headers.get("content-type") or "").lower():
                         if parse_form_data is True:
-                            try:
-                                parsed = parse_qs(request.post_data, keep_blank_values=True)
-                                flat = {k: v[0] if len(v) == 1 else v for k, v in parsed.items()}
-                                record["post_data"] = flat
-                            except Exception as e:
-                                _logger.error(e)
-                                record["post_data"] = safe_parse_literal(s=request.post_data_json)
-                        else:
-                            record["post_data"] = safe_parse_literal(s=request.post_data_json)
-                    else:
-                        record["post_data"] = safe_parse_literal(s=request.post_data)
+                            # 关键：只有当 post_data 非空且看起来像 form-urlencoded 才解析
+                            if request.post_data and "=" in request.post_data:  # 最简单的启发式判断
+                                try:
+                                    parsed = parse_qs(request.post_data, keep_blank_values=True)
+                                    flat = {k: v[0] if len(v) == 1 else v for k, v in parsed.items()}
+                                    record["post_data"] = flat
+                                except Exception as e:
+                                    _logger.error(e)
+                                    record["parse_error"] = str(e)
                 captured_records.append(record)
 
         async def handle_response(response: Response):
@@ -234,23 +249,26 @@ class BasePo(object):
                     "type": "request",
                     "url": request.url,
                     "method": request.method,
+                    "resource_type": request.resource_type,
                     "headers": dict(request.headers),
-                    "post_data": request.post_data,
+                    "post_data": safe_parse_literal(s=request.post_data),
                 }
 
                 # 解析 form-urlencoded
-                if (
-                        parse_form_data is True
-                        and request.post_data
-                        and "application/x-www-form-urlencoded" in (request.headers.get("content-type") or "").lower()
-                ):
-                    try:
-                        parsed = parse_qs(request.post_data, keep_blank_values=True)
-                        flat = {k: v[0] if len(v) == 1 else v for k, v in parsed.items()}
-                        record["post_data"] = flat
-                    except Exception as e:
-                        record["parse_error"] = str(e)
-
+                if "application/json" in (request.headers.get("content-type") or "").lower():
+                    if request.post_data_json:
+                        record["post_data"] = request.post_data_json
+                elif "application/x-www-form-urlencoded" in (request.headers.get("content-type") or "").lower():
+                    if parse_form_data is True:
+                        # 关键：只有当 post_data 非空且看起来像 form-urlencoded 才解析
+                        if request.post_data and "=" in request.post_data:  # 最简单的启发式判断
+                            try:
+                                parsed = parse_qs(request.post_data, keep_blank_values=True)
+                                flat = {k: v[0] if len(v) == 1 else v for k, v in parsed.items()}
+                                record["post_data"] = flat
+                            except Exception as e:
+                                _logger.error(e)
+                                record["parse_error"] = str(e)
                 captured.append(record)
 
             # 必须放行请求！
